@@ -102,20 +102,12 @@ class MoneyPatched(Money):
         return ''
 
     def __use_l10n(self):
-        'Return boolean'
-
-        # Do not change. The variable "self.use_l10n" has three states:
-        # True, False, and None.
-        if self.use_l10n == True:
-            return True
-
-        # Do not change. The variable "self.use_l10n" has three states:
-        # True, False, and None.
-        if self.use_l10n == False:
-            return False
-
-        # if self.use_l10n == None >>
-        return settings.USE_L10N
+        """
+        Return boolean.
+        """
+        if self.use_l10n is None:
+            return settings.USE_L10N
+        return self.use_l10n
 
     def __unicode__(self):
 
